# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_create_sequences_from_file_response import V1alphaCreateSequencesFromFileResponse

class TestV1alphaCreateSequencesFromFileResponse(unittest.TestCase):
    """V1alphaCreateSequencesFromFileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaCreateSequencesFromFileResponse:
        """Test V1alphaCreateSequencesFromFileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaCreateSequencesFromFileResponse`
        """
        model = V1alphaCreateSequencesFromFileResponse()
        if include_optional:
            return V1alphaCreateSequencesFromFileResponse(
                sequences = [
                    seqq.models.v1alpha_sequence.v1alphaSequence(
                        name = '', 
                        collection = '', 
                        sequence = '', 
                        code = 'CODE_UNSPECIFIED', 
                        taxonomy_id = '', 
                        create_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        etag = '', 
                        description = '', )
                    ]
            )
        else:
            return V1alphaCreateSequencesFromFileResponse(
        )
        """

    def testV1alphaCreateSequencesFromFileResponse(self):
        """Test V1alphaCreateSequencesFromFileResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "0.0.30"

# import apis into sdk package
from seqq.api.seqq_service_api import SeqqServiceApi

# import ApiClient
from seqq.api_response import ApiResponse
from seqq.api_client import ApiClient
from seqq.configuration import Configuration
from seqq.exceptions import OpenApiException
from seqq.exceptions import ApiTypeError
from seqq.exceptions import ApiValueError
from seqq.exceptions import ApiKeyError
from seqq.exceptions import ApiAttributeError
from seqq.exceptions import ApiException

# import models into sdk package
from seqq.models.protobuf_any import ProtobufAny
from seqq.models.rpc_status import RpcStatus
from seqq.models.search_state import SearchState
from seqq.models.seqq_service_batch_create_sequences_request import SeqqServiceBatchCreateSequencesRequest
from seqq.models.the_integration_to_update import TheIntegrationToUpdate
from seqq.models.v1alpha_batch_create_sequences_response import V1alphaBatchCreateSequencesResponse
from seqq.models.v1alpha_code import V1alphaCode
from seqq.models.v1alpha_collection import V1alphaCollection
from seqq.models.v1alpha_create_sequence_request import V1alphaCreateSequenceRequest
from seqq.models.v1alpha_create_sequences_from_file_response import V1alphaCreateSequencesFromFileResponse
from seqq.models.v1alpha_file_encoding import V1alphaFileEncoding
from seqq.models.v1alpha_hit import V1alphaHit
from seqq.models.v1alpha_integration import V1alphaIntegration
from seqq.models.v1alpha_integration_google_drive import V1alphaIntegrationGoogleDrive
from seqq.models.v1alpha_integration_ncbi import V1alphaIntegrationNCBI
from seqq.models.v1alpha_list_collections_response import V1alphaListCollectionsResponse
from seqq.models.v1alpha_list_integrations_response import V1alphaListIntegrationsResponse
from seqq.models.v1alpha_list_searches_response import V1alphaListSearchesResponse
from seqq.models.v1alpha_list_sequences_response import V1alphaListSequencesResponse
from seqq.models.v1alpha_search import V1alphaSearch
from seqq.models.v1alpha_sequence import V1alphaSequence



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_file_encoding import V1alphaFileEncoding

class TestV1alphaFileEncoding(unittest.TestCase):
    """V1alphaFileEncoding unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testV1alphaFileEncoding(self):
        """Test V1alphaFileEncoding"""
        # inst = V1alphaFileEncoding()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class V1alphaHit(BaseModel):
    """
    Hit is a single hit from a Search.
    """ # noqa: E501
    saccver: Optional[StrictStr] = Field(default=None, description="Subject accession version.")
    pident: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Percentage of identical matches.")
    length: Optional[StrictStr] = Field(default=None, description="Alignment length.")
    mismatch: Optional[StrictStr] = Field(default=None, description="Number of mismatches.")
    gapopen: Optional[StrictStr] = Field(default=None, description="Number of gap openings.")
    qstart: Optional[StrictStr] = Field(default=None, description="Start of alignment in search.")
    qend: Optional[StrictStr] = Field(default=None, description="End of alignment in search.")
    sstart: Optional[StrictStr] = Field(default=None, description="Start of alignment in subject.")
    send: Optional[StrictStr] = Field(default=None, description="End of alignment in subject.")
    evalue: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Expect value.")
    bitscore: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="Bit score.")
    __properties: ClassVar[List[str]] = ["saccver", "pident", "length", "mismatch", "gapopen", "qstart", "qend", "sstart", "send", "evalue", "bitscore"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V1alphaHit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "saccver",
            "pident",
            "length",
            "mismatch",
            "gapopen",
            "qstart",
            "qend",
            "sstart",
            "send",
            "evalue",
            "bitscore",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V1alphaHit from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "saccver": obj.get("saccver"),
            "pident": obj.get("pident"),
            "length": obj.get("length"),
            "mismatch": obj.get("mismatch"),
            "gapopen": obj.get("gapopen"),
            "qstart": obj.get("qstart"),
            "qend": obj.get("qend"),
            "sstart": obj.get("sstart"),
            "send": obj.get("send"),
            "evalue": obj.get("evalue"),
            "bitscore": obj.get("bitscore")
        })
        return _obj





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class V1alphaFileEncoding(str, Enum):
    """
    FileEncoding is the type of sequence file to upload.   - FILE_UNSPECIFIED: FILE_UNSPECIFIED is the default value.  - FASTA: FASTA is a FASTA file.  - GENBANK: GEBANK is a GenBank file.
    """

    """
    allowed enum values
    """
    FILE_UNSPECIFIED = 'FILE_UNSPECIFIED'
    FASTA = 'FASTA'
    GENBANK = 'GENBANK'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of V1alphaFileEncoding from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class ProtobufAny(BaseModel):
    """
    `Any` contains an arbitrary serialized protocol buffer message along with a URL that describes the type of the serialized message.  Protobuf library provides support to pack/unpack Any values in the form of utility functions or additional generated methods of the Any type.  Example 1: Pack and unpack a message in C++.      Foo foo = ...;     Any any;     any.PackFrom(foo);     ...     if (any.UnpackTo(&foo)) {       ...     }  Example 2: Pack and unpack a message in Java.      Foo foo = ...;     Any any = Any.pack(foo);     ...     if (any.is(Foo.class)) {       foo = any.unpack(Foo.class);     }     // or ...     if (any.isSameTypeAs(Foo.getDefaultInstance())) {       foo = any.unpack(Foo.getDefaultInstance());     }   Example 3: Pack and unpack a message in Python.      foo = Foo(...)     any = Any()     any.Pack(foo)     ...     if any.Is(Foo.DESCRIPTOR):       any.Unpack(foo)       ...   Example 4: Pack and unpack a message in Go       foo := &pb.Foo{...}      any, err := anypb.New(foo)      if err != nil {        ...      }      ...      foo := &pb.Foo{}      if err := any.UnmarshalTo(foo); err != nil {        ...      }  The pack methods provided by protobuf library will by default use 'type.googleapis.com/full.type.name' as the type URL and the unpack methods only use the fully qualified type name after the last '/' in the type URL, for example \"foo.bar.com/x/y.z\" will yield type name \"y.z\".  JSON ==== The JSON representation of an `Any` value uses the regular representation of the deserialized, embedded message, with an additional field `@type` which contains the type URL. Example:      package google.profile;     message Person {       string first_name = 1;       string last_name = 2;     }      {       \"@type\": \"type.googleapis.com/google.profile.Person\",       \"firstName\": <string>,       \"lastName\": <string>     }  If the embedded message type is well-known and has a custom JSON representation, that representation will be embedded adding a field `value` which holds the custom JSON in addition to the `@type` field. Example (for message [google.protobuf.Duration][]):      {       \"@type\": \"type.googleapis.com/google.protobuf.Duration\",       \"value\": \"1.212s\"     }
    """ # noqa: E501
    type: Optional[StrictStr] = Field(default=None, description="A URL/resource name that uniquely identifies the type of the serialized protocol buffer message. This string must contain at least one \"/\" character. The last segment of the URL's path must represent the fully qualified name of the type (as in `path/google.protobuf.Duration`). The name should be in a canonical form (e.g., leading \".\" is not accepted).  In practice, teams usually precompile into the binary all types that they expect it to use in the context of Any. However, for URLs which use the scheme `http`, `https`, or no scheme, one can optionally set up a type server that maps type URLs to message definitions as follows:  * If no scheme is provided, `https` is assumed. * An HTTP GET on the URL must yield a [google.protobuf.Type][]   value in binary format, or produce an error. * Applications are allowed to cache lookup results based on the   URL, or have them precompiled into a binary to avoid any   lookup. Therefore, binary compatibility needs to be preserved   on changes to types. (Use versioned type names to manage   breaking changes.)  Note: this functionality is not currently available in the official protobuf release, and it is not used for type URLs beginning with type.googleapis.com. As of May 2023, there are no widely used type server implementations and no plans to implement one.  Schemes other than `http`, `https` (or the empty scheme) might be used with implementation specific semantics.", alias="@type")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["@type"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProtobufAny from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProtobufAny from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "@type": obj.get("@type")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from seqq.models.rpc_status import RpcStatus
from seqq.models.search_state import SearchState
from seqq.models.v1alpha_code import V1alphaCode
from seqq.models.v1alpha_hit import V1alphaHit
from typing import Optional, Set
from typing_extensions import Self

class V1alphaSearch(BaseModel):
    """
    A Search of the Sequences in a Collection.  On creation, Searches direct seqq to start a query against a Collection using a chosen `program`. On reads, Searches contain the results of the query, including its current `state` and any `hits`.
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="The globally unique name of the Serach. Format is `collections/{collection_id}/searches/{search_id}`.")
    query: StrictStr = Field(description="The sequence of nucleoties or amino acids to search the Collection for.")
    code: Optional[V1alphaCode] = None
    prefix: Optional[StrictStr] = Field(default=None, description="An optional \"/\" separated prefix to limit searches to.")
    query_time: Optional[datetime] = Field(default=None, description="The time a search start is started.", alias="queryTime")
    query_duration: Optional[StrictStr] = Field(default=None, description="The duration of a search from start to completion.", alias="queryDuration")
    hits: Optional[List[V1alphaHit]] = Field(default=None, description="A list of hits from the Search. This is only set when `state` is `SUCCEEDED`.")
    state: Optional[SearchState] = None
    error: Optional[RpcStatus] = None
    blastn: Optional[Dict[str, Any]] = Field(default=None, description="Blastn is a blastn search.")
    blastp: Optional[Dict[str, Any]] = Field(default=None, description="Blastp is a blastp search.")
    blastx: Optional[Dict[str, Any]] = Field(default=None, description="Blastp is a blastp search.")
    tblastn: Optional[Dict[str, Any]] = Field(default=None, description="Tblastn is a tblastn search.")
    tblastx: Optional[Dict[str, Any]] = Field(default=None, description="Tblastx is a tblastx search.")
    __properties: ClassVar[List[str]] = ["name", "query", "code", "prefix", "queryTime", "queryDuration", "hits", "state", "error", "blastn", "blastp", "blastx", "tblastn", "tblastx"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V1alphaSearch from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "query_time",
            "query_duration",
            "hits",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in hits (list)
        _items = []
        if self.hits:
            for _item in self.hits:
                if _item:
                    _items.append(_item.to_dict())
            _dict['hits'] = _items
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict['error'] = self.error.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V1alphaSearch from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "query": obj.get("query"),
            "code": obj.get("code"),
            "prefix": obj.get("prefix"),
            "queryTime": obj.get("queryTime"),
            "queryDuration": obj.get("queryDuration"),
            "hits": [V1alphaHit.from_dict(_item) for _item in obj["hits"]] if obj.get("hits") is not None else None,
            "state": obj.get("state"),
            "error": RpcStatus.from_dict(obj["error"]) if obj.get("error") is not None else None,
            "blastn": obj.get("blastn"),
            "blastp": obj.get("blastp"),
            "blastx": obj.get("blastx"),
            "tblastn": obj.get("tblastn"),
            "tblastx": obj.get("tblastx")
        })
        return _obj





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from seqq.models.v1alpha_integration_google_drive import V1alphaIntegrationGoogleDrive
from seqq.models.v1alpha_integration_ncbi import V1alphaIntegrationNCBI
from typing import Optional, Set
from typing_extensions import Self

class TheIntegrationToUpdate(BaseModel):
    """
    TheIntegrationToUpdate
    """ # noqa: E501
    collection: StrictStr = Field(description="The name of the Collection that the Integration imports Sequences to. Format is `collections/{collection_id}`.")
    sequence_id_prefix: Optional[StrictStr] = Field(default=None, description="A prefix that is prepended to all Sequence IDs added to the Collection.  For example, if \"proteins/flourescent\" is imported to a Collection \"my-collection\", and a Sequence with an ID of \"GFP\" is imported, the Sequence name will be \"collections/my-collection/sequences/proteins/flourescent/GFP\".", alias="sequenceIdPrefix")
    etag: Optional[StrictStr] = Field(default=None, description="An opaque, server-assigned value that is the hash of all fields in the Integration. Each change to an integration changes the Etag value.")
    ncbi: Optional[V1alphaIntegrationNCBI] = None
    google_drive: Optional[V1alphaIntegrationGoogleDrive] = Field(default=None, alias="googleDrive")
    __properties: ClassVar[List[str]] = ["collection", "sequenceIdPrefix", "etag", "ncbi", "googleDrive"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TheIntegrationToUpdate from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of ncbi
        if self.ncbi:
            _dict['ncbi'] = self.ncbi.to_dict()
        # override the default output from pydantic by calling `to_dict()` of google_drive
        if self.google_drive:
            _dict['googleDrive'] = self.google_drive.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TheIntegrationToUpdate from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "collection": obj.get("collection"),
            "sequenceIdPrefix": obj.get("sequenceIdPrefix"),
            "etag": obj.get("etag"),
            "ncbi": V1alphaIntegrationNCBI.from_dict(obj["ncbi"]) if obj.get("ncbi") is not None else None,
            "googleDrive": V1alphaIntegrationGoogleDrive.from_dict(obj["googleDrive"]) if obj.get("googleDrive") is not None else None
        })
        return _obj





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class V1alphaCode(str, Enum):
    """
    Code is the type of sequence.   - CODE_UNSPECIFIED: CODE_UNSPECIFIED is the default value.  - NUCLEIC: NUCLEIC is a nucleic acid sequence.  - PROTEIN: PROTEIN is an amino acid sequence.
    """

    """
    allowed enum values
    """
    CODE_UNSPECIFIED = 'CODE_UNSPECIFIED'
    NUCLEIC = 'NUCLEIC'
    PROTEIN = 'PROTEIN'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of V1alphaCode from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_search import V1alphaSearch

class TestV1alphaSearch(unittest.TestCase):
    """V1alphaSearch unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaSearch:
        """Test V1alphaSearch
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaSearch`
        """
        model = V1alphaSearch()
        if include_optional:
            return V1alphaSearch(
                name = '',
                query = '',
                code = 'CODE_UNSPECIFIED',
                prefix = '',
                query_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                query_duration = '',
                hits = [
                    seqq.models.v1alpha_hit.v1alphaHit(
                        saccver = '', 
                        pident = 1.337, 
                        length = '', 
                        mismatch = '', 
                        gapopen = '', 
                        qstart = '', 
                        qend = '', 
                        sstart = '', 
                        send = '', 
                        evalue = 1.337, 
                        bitscore = 1.337, )
                    ],
                state = 'STATE_UNSPECIFIED',
                error = seqq.models.rpc_status.rpcStatus(
                    code = 56, 
                    message = '', 
                    details = [
                        {
                            'key' : None
                            }
                        ], ),
                blastn = seqq.models.v1alpha_blastn.v1alphaBlastn(),
                blastp = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                blastx = seqq.models.v1alpha_blastp.v1alphaBlastp(),
                tblastn = seqq.models.v1alpha_tblastn.v1alphaTblastn(),
                tblastx = seqq.models.v1alpha_tblastx.v1alphaTblastx()
            )
        else:
            return V1alphaSearch(
                query = '',
        )
        """

    def testV1alphaSearch(self):
        """Test V1alphaSearch"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from seqq.models.v1alpha_integration import V1alphaIntegration

class TestV1alphaIntegration(unittest.TestCase):
    """V1alphaIntegration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V1alphaIntegration:
        """Test V1alphaIntegration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `V1alphaIntegration`
        """
        model = V1alphaIntegration()
        if include_optional:
            return V1alphaIntegration(
                collection = '',
                name = '',
                sequence_id_prefix = '',
                etag = '',
                ncbi = seqq.models.v1alpha_integration_ncbi.v1alphaIntegrationNCBI(
                    manifest = '', 
                    uploads = {
                        'key' : ''
                        }, ),
                google_drive = seqq.models.v1alpha_integration_google_drive.v1alphaIntegrationGoogleDrive(
                    service_account_credentials = 'YQ==', )
            )
        else:
            return V1alphaIntegration(
                collection = '',
        )
        """

    def testV1alphaIntegration(self):
        """Test V1alphaIntegration"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from seqq.models.v1alpha_code import V1alphaCode
from typing import Optional, Set
from typing_extensions import Self

class V1alphaSequence(BaseModel):
    """
    Sequence is a single entry containing nucleotides or amino acids and other optional metadata like a description, creation time, and taxonomy ID.
    """ # noqa: E501
    name: Optional[StrictStr] = Field(default=None, description="Name of the Sequence. Format: `collections/{collection_id}/sequences/{sequence_id}`.")
    collection: Optional[StrictStr] = Field(default=None, description="The `name` of the Collection the Sequence belongs to. Format: `collections/{collection_id}`.")
    sequence: StrictStr = Field(description="A sequence of nucleotides or amino acids. Only characters in the IUPAC alphabets are allowed.")
    code: Optional[V1alphaCode] = None
    taxonomy_id: Optional[StrictStr] = Field(default=None, description="The taxonomy ID of the sequence in NCBI's Taxonomy database. This can be used to filter BLAST search results.", alias="taxonomyId")
    create_time: Optional[datetime] = Field(default=None, description="The time that the Sequence was created. This is set once on creation by the server.", alias="createTime")
    etag: Optional[StrictStr] = Field(default=None, description="An opaque, server-assigned value that is a hash of all other fields in the Sequence resource. This is used during deletes to ensure stale Sequences are excluded from Search responses.")
    description: Optional[StrictStr] = Field(default=None, description="A description of the Sequence. For Sequences from FASTA files, this is the entire description line without the leading \">\". For Sequences from GenBank files, this is from the Description field.")
    __properties: ClassVar[List[str]] = ["name", "collection", "sequence", "code", "taxonomyId", "createTime", "etag", "description"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V1alphaSequence from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "collection",
            "create_time",
            "etag",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V1alphaSequence from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "collection": obj.get("collection"),
            "sequence": obj.get("sequence"),
            "code": obj.get("code"),
            "taxonomyId": obj.get("taxonomyId"),
            "createTime": obj.get("createTime"),
            "etag": obj.get("etag"),
            "description": obj.get("description")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from seqq.models.protobuf_any import ProtobufAny
from seqq.models.rpc_status import RpcStatus
from seqq.models.search_state import SearchState
from seqq.models.seqq_service_batch_create_sequences_request import SeqqServiceBatchCreateSequencesRequest
from seqq.models.the_integration_to_update import TheIntegrationToUpdate
from seqq.models.v1alpha_batch_create_sequences_response import V1alphaBatchCreateSequencesResponse
from seqq.models.v1alpha_code import V1alphaCode
from seqq.models.v1alpha_collection import V1alphaCollection
from seqq.models.v1alpha_create_sequence_request import V1alphaCreateSequenceRequest
from seqq.models.v1alpha_create_sequences_from_file_response import V1alphaCreateSequencesFromFileResponse
from seqq.models.v1alpha_file_encoding import V1alphaFileEncoding
from seqq.models.v1alpha_hit import V1alphaHit
from seqq.models.v1alpha_integration import V1alphaIntegration
from seqq.models.v1alpha_integration_google_drive import V1alphaIntegrationGoogleDrive
from seqq.models.v1alpha_integration_ncbi import V1alphaIntegrationNCBI
from seqq.models.v1alpha_list_collections_response import V1alphaListCollectionsResponse
from seqq.models.v1alpha_list_integrations_response import V1alphaListIntegrationsResponse
from seqq.models.v1alpha_list_searches_response import V1alphaListSearchesResponse
from seqq.models.v1alpha_list_sequences_response import V1alphaListSequencesResponse
from seqq.models.v1alpha_search import V1alphaSearch
from seqq.models.v1alpha_sequence import V1alphaSequence



# coding: utf-8

"""
    seqq

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class V1alphaIntegrationNCBI(BaseModel):
    """
    NCBI integration.
    """ # noqa: E501
    manifest: StrictStr = Field(description="The URL of an NCBI manifest to import Sequences from. These are from the BLAST FTP website. For example, \"https://ftp.ncbi.nlm.nih.gov/blast/db/taxdb-metadata.json\" imports Sequences from the NCBI Taxonomy database.")
    uploads: Optional[Dict[str, StrictStr]] = Field(default=None, description="A map from file name to the count of sequences uploaded from that file. Files do not change in NCBI. This field is set by the server so integrations can skip sequence uploading if the sequences has already been uploaded. These are set when we fail to upload a single sequence within the file.")
    __properties: ClassVar[List[str]] = ["manifest", "uploads"]

    model_config = {
        "populate_by_name": True,
        "validate_assignment": True,
        "protected_namespaces": (),
    }


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V1alphaIntegrationNCBI from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "uploads",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V1alphaIntegrationNCBI from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "manifest": obj.get("manifest"),
            "uploads": obj.get("uploads")
        })
        return _obj


